@@ -22,6 +22,7 @@
 #include <QDir>
 #include <QFileInfo>
 #include <QList>
+#include <QMimeData>
 #include <QMimeDatabase>
 #include <QIcon>
 #include <QStack>
@@ -46,7 +47,7 @@ public:
     enum Flag { None = 0, Dir = 1, Modified = 2, ModifiedExternally = 4, DeletedExternally = 8, Empty = 16, ShowFullPath = 32, Host = 64 };
     Q_DECLARE_FLAGS(Flags, Flag)
 
-    ProxyItem(const QString &n, ProxyItemDir *p = 0, Flags f = ProxyItem::None);
+    ProxyItem(const QString &n, ProxyItemDir *p = nullptr, Flags f = ProxyItem::None);
     ~ProxyItem();
 
     int addChild(ProxyItem *p);
@@ -124,7 +125,7 @@ QDebug operator<<(QDebug dbg, ProxyItem *item)
 class ProxyItemDir : public ProxyItem
 {
 public:
-    ProxyItemDir(QString n, ProxyItemDir *p = 0) : ProxyItem(n, p) {
+    ProxyItemDir(QString n, ProxyItemDir *p = nullptr) : ProxyItem(n, p) {
         setFlag(ProxyItem::Dir);
         updateDisplay();
 
@@ -151,7 +152,7 @@ Q_DECLARE_OPERATORS_FOR_FLAGS(ProxyItem::Flags)
 
 //BEGIN ProxyItem
 ProxyItem::ProxyItem(const QString &d, ProxyItemDir *p, ProxyItem::Flags f)
-    : m_path(d), m_parent(Q_NULLPTR), m_row(-1), m_flags(f), m_doc(0)
+    : m_path(d), m_parent(Q_NULLPTR), m_row(-1), m_flags(f), m_doc(nullptr)
 {
     updateDisplay();
 
@@ -217,7 +218,7 @@ void ProxyItem::remChild(ProxyItem *item)
         m_children[i]->m_row = i;
     }
 
-    item->m_parent = 0;
+    item->m_parent = nullptr;
 }
 
 ProxyItemDir *ProxyItem::parent() const
@@ -363,7 +364,7 @@ void ProxyItem::updateDocumentName()
 
 KateFileTreeModel::KateFileTreeModel(QObject *p)
     : QAbstractItemModel(p)
-    , m_root(new ProxyItemDir(QLatin1String("m_root"), 0))
+    , m_root(new ProxyItemDir(QLatin1String("m_root"), nullptr))
 {
     // setup default settings
     // session init will set these all soon
@@ -449,7 +450,7 @@ void KateFileTreeModel::clearModel()
     beginRemoveRows(QModelIndex(), 0, qMax(m_root->childCount() - 1, 0));
 
     delete m_root;
-    m_root = new ProxyItemDir(QLatin1String("m_root"), 0);
+    m_root = new ProxyItemDir(QLatin1String("m_root"), nullptr);
 
     m_docmap.clear();
     m_viewHistory.clear();
@@ -461,9 +462,9 @@ void KateFileTreeModel::clearModel()
 
 void KateFileTreeModel::connectDocument(const KTextEditor::Document *doc)
 {
-    connect(doc, SIGNAL(documentNameChanged(KTextEditor::Document *)), this, SLOT(documentNameChanged(KTextEditor::Document *)));
-    connect(doc, SIGNAL(documentUrlChanged(KTextEditor::Document *)), this, SLOT(documentNameChanged(KTextEditor::Document *)));
-    connect(doc, SIGNAL(modifiedChanged(KTextEditor::Document *)), this, SLOT(documentModifiedChanged(KTextEditor::Document *)));
+    connect(doc, &KTextEditor::Document::documentNameChanged, this, &KateFileTreeModel::documentNameChanged);
+    connect(doc, &KTextEditor::Document::documentUrlChanged, this, &KateFileTreeModel::documentNameChanged);
+    connect(doc, &KTextEditor::Document::modifiedChanged, this, &KateFileTreeModel::documentModifiedChanged);
     connect(doc, SIGNAL(modifiedOnDisk(KTextEditor::Document *, bool, KTextEditor::ModificationInterface::ModifiedOnDiskReason)),
             this,  SLOT(documentModifiedOnDisc(KTextEditor::Document *, bool, KTextEditor::ModificationInterface::ModifiedOnDiskReason)));
 }
@@ -484,12 +485,18 @@ Qt::ItemFlags KateFileTreeModel::flags(const QModelIndex &index) const
     Qt::ItemFlags flags = Qt::ItemIsEnabled;
 
     if (!index.isValid()) {
-        return 0;
+        return nullptr;
     }
 
     const ProxyItem *item = static_cast<ProxyItem *>(index.internalPointer());
-    if (item && !item->childCount()) {
-        flags |= Qt::ItemIsSelectable;
+    if (item) {
+        if (!item->childCount()) {
+            flags |= Qt::ItemIsSelectable;
+        }
+
+        if (item->doc() && item->doc()->url().isValid()) {
+            flags |= Qt::ItemIsDragEnabled;
+        }
     }
 
     return flags;
@@ -561,6 +568,28 @@ QVariant KateFileTreeModel::data(const QModelIndex &index, int role) const
     return QVariant();
 }
 
+QMimeData *KateFileTreeModel::mimeData(const QModelIndexList &indexes) const
+{
+    QList<QUrl> urls;
+
+    for (const auto &index : indexes) {
+        ProxyItem *item = static_cast<ProxyItem *>(index.internalPointer());
+        if (!item || !item->doc() || !item->doc()->url().isValid()) {
+            continue;
+        }
+
+        urls.append(item->doc()->url());
+    }
+
+    if (urls.isEmpty()) {
+        return nullptr;
+    }
+
+    QMimeData *mimeData = new QMimeData();
+    mimeData->setUrls(urls);
+    return mimeData;
+}
+
 QVariant KateFileTreeModel::headerData(int section, Qt::Orientation orientation, int role) const
 {
     Q_UNUSED(orientation);
@@ -617,7 +646,7 @@ QModelIndex KateFileTreeModel::parent(const QModelIndex &index) const
 
 QModelIndex KateFileTreeModel::index(int row, int column, const QModelIndex &parent) const
 {
-    const ProxyItem *p = 0;
+    const ProxyItem *p = nullptr;
     if (column != 0) {
         return QModelIndex();
     }
@@ -795,9 +824,9 @@ void KateFileTreeModel::documentEdited(const KTextEditor::Document *doc)
 void KateFileTreeModel::slotAboutToDeleteDocuments(const QList<KTextEditor::Document *> &docs)
 {
     foreach(const KTextEditor::Document * doc, docs) {
-        disconnect(doc, SIGNAL(documentNameChanged(KTextEditor::Document *)), this, SLOT(documentNameChanged(KTextEditor::Document *)));
-        disconnect(doc, SIGNAL(documentUrlChanged(KTextEditor::Document *)), this, SLOT(documentNameChanged(KTextEditor::Document *)));
-        disconnect(doc, SIGNAL(modifiedChanged(KTextEditor::Document *)), this, SLOT(documentModifiedChanged(KTextEditor::Document *)));
+        disconnect(doc, &KTextEditor::Document::documentNameChanged, this, &KateFileTreeModel::documentNameChanged);
+        disconnect(doc, &KTextEditor::Document::documentUrlChanged, this, &KateFileTreeModel::documentNameChanged);
+        disconnect(doc, &KTextEditor::Document::modifiedChanged, this, &KateFileTreeModel::documentModifiedChanged);
         disconnect(doc, SIGNAL(modifiedOnDisk(KTextEditor::Document *, bool, KTextEditor::ModificationInterface::ModifiedOnDiskReason)),
                    this,  SLOT(documentModifiedOnDisc(KTextEditor::Document *, bool, KTextEditor::ModificationInterface::ModifiedOnDiskReason)));
     }
@@ -870,13 +899,15 @@ void KateFileTreeModel::updateBackgrounds(bool force)
         m_brushes[it.key()] = QBrush(KColorUtils::mix(QPalette().color(QPalette::Base), shade, t));
     }
 
-    foreach(ProxyItem * item, m_brushes.keys()) {
+    for (auto it = m_brushes.constBegin(), end = m_brushes.constEnd(); it != end; ++it) {
+        ProxyItem *item = it.key();
         oldBrushes.remove(item);
         const QModelIndex idx = createIndex(item->row(), 0, item);
         dataChanged(idx, idx);
     }
 
-    foreach(ProxyItem * item, oldBrushes.keys()) {
+    for (auto it = oldBrushes.constBegin(), end = oldBrushes.constEnd(); it != end; ++it) {
+        ProxyItem *item = it.key();
         const QModelIndex idx = createIndex(item->row(), 0, item);
         dataChanged(idx, idx);
     }
@@ -884,7 +915,7 @@ void KateFileTreeModel::updateBackgrounds(bool force)
 
 void KateFileTreeModel::handleEmptyParents(ProxyItemDir *item)
 {
-    Q_ASSERT(item != 0);
+    Q_ASSERT(item != nullptr);
 
     if (!item->parent()) {
         return;
@@ -998,16 +1029,16 @@ ProxyItemDir *KateFileTreeModel::findRootNode(const QString &name, const int r)
         }
     }
 
-    return 0;
+    return nullptr;
 }
 
 ProxyItemDir *KateFileTreeModel::findChildNode(const ProxyItemDir *parent, const QString &name) const
 {
-    Q_ASSERT(parent != 0);
+    Q_ASSERT(parent != nullptr);
     Q_ASSERT(!name.isEmpty());
 
     if (!parent->childCount()) {
-        return 0;
+        return nullptr;
     }
 
     foreach(ProxyItem * item, parent->children()) {
@@ -1020,13 +1051,13 @@ ProxyItemDir *KateFileTreeModel::findChildNode(const ProxyItemDir *parent, const
         }
     }
 
-    return 0;
+    return nullptr;
 }
 
 void KateFileTreeModel::insertItemInto(ProxyItemDir *root, ProxyItem *item)
 {
-    Q_ASSERT(root != 0);
-    Q_ASSERT(item != 0);
+    Q_ASSERT(root != nullptr);
+    Q_ASSERT(item != nullptr);
 
     QString tail = item->path();
     tail.remove(0, root->path().length());
@@ -1062,7 +1093,7 @@ void KateFileTreeModel::insertItemInto(ProxyItemDir *root, ProxyItem *item)
 
 void KateFileTreeModel::handleInsert(ProxyItem *item)
 {
-    Q_ASSERT(item != 0);
+    Q_ASSERT(item != nullptr);
 
     if (m_listMode || item->flag(ProxyItem::Empty)) {
         beginInsertRows(QModelIndex(), m_root->childCount(), m_root->childCount());
@@ -1207,7 +1238,7 @@ void KateFileTreeModel::handleDuplicitRootDisplay(ProxyItemDir *init)
 
 void KateFileTreeModel::handleNameChange(ProxyItem *item)
 {
-    Q_ASSERT(item != 0);
+    Q_ASSERT(item != nullptr);
     Q_ASSERT(item->parent());
 
     updateItemPathAndHost(item);
@@ -1269,7 +1300,7 @@ void KateFileTreeModel::updateItemPathAndHost(ProxyItem *item) const
 
 void KateFileTreeModel::setupIcon(ProxyItem *item) const
 {
-    Q_ASSERT(item != 0);
+    Q_ASSERT(item != nullptr);
 
     QString icon_name;
 
